# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/admiral/user_application_instance/v0/user_application_instance_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.admiral.user_application_instance.v0 import user_application_instance_pb2 as qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQqwak/admiral/user_application_instance/v0/user_application_instance_service.proto\x12!qwak.admiral.user_app_instance.v0\x1aIqwak/admiral/user_application_instance/v0/user_application_instance.proto\"p\n$CreateUserApplicationInstanceRequest\x12H\n\x0e\x63reate_options\x18\x01 \x01(\x0b\x32\x30.qwak.admiral.user_app_instance.v0.CreateOptions\"\'\n%CreateUserApplicationInstanceResponse\"x\n(UpdateUserApplicationInstanceSpecRequest\x12L\n\x0eupdate_options\x18\x01 \x01(\x0b\x32\x34.qwak.admiral.user_app_instance.v0.UpdateSpecOptions\"+\n)UpdateUserApplicationInstanceSpecResponse\"f\n!GetUserApplicationInstanceRequest\x12\x41\n\nidentifier\x18\x01 \x01(\x0b\x32-.qwak.admiral.user_app_instance.v0.Identifier\"i\n\"GetUserApplicationInstanceResponse\x12\x43\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32..qwak.admiral.user_app_instance.v0.Description\"i\n$DeleteUserApplicationInstanceRequest\x12\x41\n\nidentifier\x18\x01 \x01(\x0b\x32-.qwak.admiral.user_app_instance.v0.Identifier\"\'\n%DeleteUserApplicationInstanceResponse2\xf7\x05\n\x1eUserApplicationInstanceService\x12\xb2\x01\n\x1d\x43reateUserApplicationInstance\x12G.qwak.admiral.user_app_instance.v0.CreateUserApplicationInstanceRequest\x1aH.qwak.admiral.user_app_instance.v0.CreateUserApplicationInstanceResponse\x12\xbe\x01\n!UpdateUserApplicationInstanceSpec\x12K.qwak.admiral.user_app_instance.v0.UpdateUserApplicationInstanceSpecRequest\x1aL.qwak.admiral.user_app_instance.v0.UpdateUserApplicationInstanceSpecResponse\x12\xa9\x01\n\x1aGetUserApplicationInstance\x12\x44.qwak.admiral.user_app_instance.v0.GetUserApplicationInstanceRequest\x1a\x45.qwak.admiral.user_app_instance.v0.GetUserApplicationInstanceResponse\x12\xb2\x01\n\x1d\x44\x65leteUserApplicationInstance\x12G.qwak.admiral.user_app_instance.v0.DeleteUserApplicationInstanceRequest\x1aH.qwak.admiral.user_app_instance.v0.DeleteUserApplicationInstanceResponseB\xbe\x01\n(com.qwak.ai.admiral.user_app_instance.v0P\x01Z\x8f\x01github.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/user_application_instance/v0;user_application_instance_v0b\x06proto3')



_CREATEUSERAPPLICATIONINSTANCEREQUEST = DESCRIPTOR.message_types_by_name['CreateUserApplicationInstanceRequest']
_CREATEUSERAPPLICATIONINSTANCERESPONSE = DESCRIPTOR.message_types_by_name['CreateUserApplicationInstanceResponse']
_UPDATEUSERAPPLICATIONINSTANCESPECREQUEST = DESCRIPTOR.message_types_by_name['UpdateUserApplicationInstanceSpecRequest']
_UPDATEUSERAPPLICATIONINSTANCESPECRESPONSE = DESCRIPTOR.message_types_by_name['UpdateUserApplicationInstanceSpecResponse']
_GETUSERAPPLICATIONINSTANCEREQUEST = DESCRIPTOR.message_types_by_name['GetUserApplicationInstanceRequest']
_GETUSERAPPLICATIONINSTANCERESPONSE = DESCRIPTOR.message_types_by_name['GetUserApplicationInstanceResponse']
_DELETEUSERAPPLICATIONINSTANCEREQUEST = DESCRIPTOR.message_types_by_name['DeleteUserApplicationInstanceRequest']
_DELETEUSERAPPLICATIONINSTANCERESPONSE = DESCRIPTOR.message_types_by_name['DeleteUserApplicationInstanceResponse']
CreateUserApplicationInstanceRequest = _reflection.GeneratedProtocolMessageType('CreateUserApplicationInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERAPPLICATIONINSTANCEREQUEST,
  '__module__' : 'qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.user_app_instance.v0.CreateUserApplicationInstanceRequest)
  })
_sym_db.RegisterMessage(CreateUserApplicationInstanceRequest)

CreateUserApplicationInstanceResponse = _reflection.GeneratedProtocolMessageType('CreateUserApplicationInstanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERAPPLICATIONINSTANCERESPONSE,
  '__module__' : 'qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.user_app_instance.v0.CreateUserApplicationInstanceResponse)
  })
_sym_db.RegisterMessage(CreateUserApplicationInstanceResponse)

UpdateUserApplicationInstanceSpecRequest = _reflection.GeneratedProtocolMessageType('UpdateUserApplicationInstanceSpecRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERAPPLICATIONINSTANCESPECREQUEST,
  '__module__' : 'qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.user_app_instance.v0.UpdateUserApplicationInstanceSpecRequest)
  })
_sym_db.RegisterMessage(UpdateUserApplicationInstanceSpecRequest)

UpdateUserApplicationInstanceSpecResponse = _reflection.GeneratedProtocolMessageType('UpdateUserApplicationInstanceSpecResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERAPPLICATIONINSTANCESPECRESPONSE,
  '__module__' : 'qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.user_app_instance.v0.UpdateUserApplicationInstanceSpecResponse)
  })
_sym_db.RegisterMessage(UpdateUserApplicationInstanceSpecResponse)

GetUserApplicationInstanceRequest = _reflection.GeneratedProtocolMessageType('GetUserApplicationInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERAPPLICATIONINSTANCEREQUEST,
  '__module__' : 'qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.user_app_instance.v0.GetUserApplicationInstanceRequest)
  })
_sym_db.RegisterMessage(GetUserApplicationInstanceRequest)

GetUserApplicationInstanceResponse = _reflection.GeneratedProtocolMessageType('GetUserApplicationInstanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERAPPLICATIONINSTANCERESPONSE,
  '__module__' : 'qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.user_app_instance.v0.GetUserApplicationInstanceResponse)
  })
_sym_db.RegisterMessage(GetUserApplicationInstanceResponse)

DeleteUserApplicationInstanceRequest = _reflection.GeneratedProtocolMessageType('DeleteUserApplicationInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUSERAPPLICATIONINSTANCEREQUEST,
  '__module__' : 'qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.user_app_instance.v0.DeleteUserApplicationInstanceRequest)
  })
_sym_db.RegisterMessage(DeleteUserApplicationInstanceRequest)

DeleteUserApplicationInstanceResponse = _reflection.GeneratedProtocolMessageType('DeleteUserApplicationInstanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUSERAPPLICATIONINSTANCERESPONSE,
  '__module__' : 'qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.admiral.user_app_instance.v0.DeleteUserApplicationInstanceResponse)
  })
_sym_db.RegisterMessage(DeleteUserApplicationInstanceResponse)

_USERAPPLICATIONINSTANCESERVICE = DESCRIPTOR.services_by_name['UserApplicationInstanceService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.qwak.ai.admiral.user_app_instance.v0P\001Z\217\001github.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/user_application_instance/v0;user_application_instance_v0'
  _CREATEUSERAPPLICATIONINSTANCEREQUEST._serialized_start=195
  _CREATEUSERAPPLICATIONINSTANCEREQUEST._serialized_end=307
  _CREATEUSERAPPLICATIONINSTANCERESPONSE._serialized_start=309
  _CREATEUSERAPPLICATIONINSTANCERESPONSE._serialized_end=348
  _UPDATEUSERAPPLICATIONINSTANCESPECREQUEST._serialized_start=350
  _UPDATEUSERAPPLICATIONINSTANCESPECREQUEST._serialized_end=470
  _UPDATEUSERAPPLICATIONINSTANCESPECRESPONSE._serialized_start=472
  _UPDATEUSERAPPLICATIONINSTANCESPECRESPONSE._serialized_end=515
  _GETUSERAPPLICATIONINSTANCEREQUEST._serialized_start=517
  _GETUSERAPPLICATIONINSTANCEREQUEST._serialized_end=619
  _GETUSERAPPLICATIONINSTANCERESPONSE._serialized_start=621
  _GETUSERAPPLICATIONINSTANCERESPONSE._serialized_end=726
  _DELETEUSERAPPLICATIONINSTANCEREQUEST._serialized_start=728
  _DELETEUSERAPPLICATIONINSTANCEREQUEST._serialized_end=833
  _DELETEUSERAPPLICATIONINSTANCERESPONSE._serialized_start=835
  _DELETEUSERAPPLICATIONINSTANCERESPONSE._serialized_end=874
  _USERAPPLICATIONINSTANCESERVICE._serialized_start=877
  _USERAPPLICATIONINSTANCESERVICE._serialized_end=1636
# @@protoc_insertion_point(module_scope)
