# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/jobs/job_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.jobs import job_pb2 as qwak_dot_feature__store_dot_jobs_dot_job__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)qwak/feature_store/jobs/job_service.proto\x12\x17qwak.feature.store.jobs\x1a!qwak/feature_store/jobs/job.proto\"\x91\x01\n\x0f\x41pplyJobRequest\x12\x36\n\njob_record\x18\x01 \x01(\x0b\x32\".qwak.feature.store.jobs.JobRecord\x12\x11\n\tlogs_path\x18\x02 \x01(\t\x12\x12\n\npartner_id\x18\x03 \x01(\t\x12\x1f\n\x17\x65rror_technical_details\x18\x04 \x01(\t\"*\n\x10\x41pplyJobResponse\x12\x16\n\x0ejob_running_id\x18\x01 \x01(\x03\"1\n\x15InitPaginationRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\"?\n\x16InitPaginationResponse\x12\x14\n\x0crecord_count\x18\x01 \x01(\x05\x12\x0f\n\x07last_id\x18\x02 \x01(\x03\"e\n\x0fListJobsRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x13\n\x0bpage_number\x18\x03 \x01(\x05\x12\x10\n\x08\x61\x66ter_id\x18\x04 \x01(\x03\"M\n\x10ListJobsResponse\x12\x39\n\x04jobs\x18\x01 \x03(\x0b\x32+.qwak.feature.store.jobs.ElaborateJobRecord\"#\n\x11GetJobLogsRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\".\n\x12GetJobLogsResponse\x12\x18\n\x10logs_folder_path\x18\x01 \x01(\t\"M\n\x1dGetLatestSuccessfulJobRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\x12\x12\n\npartner_id\x18\x02 \x01(\t\"i\n\x1eGetLatestSuccessfulJobResponse\x12\x38\n\x03job\x18\x01 \x01(\x0b\x32+.qwak.feature.store.jobs.ElaborateJobRecord\x12\r\n\x05\x66ound\x18\x02 \x01(\x08\"7\n\x1b\x44\x65leteFeatureSetJobsRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\"A\n\x1c\x44\x65leteFeatureSetJobsResponse\x12!\n\x19\x64\x65leted_job_records_count\x18\x01 \x01(\x05\x32\xba\x05\n\nJobService\x12_\n\x08\x41pplyJob\x12(.qwak.feature.store.jobs.ApplyJobRequest\x1a).qwak.feature.store.jobs.ApplyJobResponse\x12q\n\x0eInitPagination\x12..qwak.feature.store.jobs.InitPaginationRequest\x1a/.qwak.feature.store.jobs.InitPaginationResponse\x12_\n\x08ListJobs\x12(.qwak.feature.store.jobs.ListJobsRequest\x1a).qwak.feature.store.jobs.ListJobsResponse\x12\x65\n\nGetJobLogs\x12*.qwak.feature.store.jobs.GetJobLogsRequest\x1a+.qwak.feature.store.jobs.GetJobLogsResponse\x12\x89\x01\n\x16GetLatestSuccessfulJob\x12\x36.qwak.feature.store.jobs.GetLatestSuccessfulJobRequest\x1a\x37.qwak.feature.store.jobs.GetLatestSuccessfulJobResponse\x12\x83\x01\n\x14\x44\x65leteFeatureSetJobs\x12\x34.qwak.feature.store.jobs.DeleteFeatureSetJobsRequest\x1a\x35.qwak.feature.store.jobs.DeleteFeatureSetJobsResponseB:\n\"com.qwak.ai.feature.store.jobs.apiP\x01Z\x12qwak/fsjobs;fsjobsb\x06proto3')



_APPLYJOBREQUEST = DESCRIPTOR.message_types_by_name['ApplyJobRequest']
_APPLYJOBRESPONSE = DESCRIPTOR.message_types_by_name['ApplyJobResponse']
_INITPAGINATIONREQUEST = DESCRIPTOR.message_types_by_name['InitPaginationRequest']
_INITPAGINATIONRESPONSE = DESCRIPTOR.message_types_by_name['InitPaginationResponse']
_LISTJOBSREQUEST = DESCRIPTOR.message_types_by_name['ListJobsRequest']
_LISTJOBSRESPONSE = DESCRIPTOR.message_types_by_name['ListJobsResponse']
_GETJOBLOGSREQUEST = DESCRIPTOR.message_types_by_name['GetJobLogsRequest']
_GETJOBLOGSRESPONSE = DESCRIPTOR.message_types_by_name['GetJobLogsResponse']
_GETLATESTSUCCESSFULJOBREQUEST = DESCRIPTOR.message_types_by_name['GetLatestSuccessfulJobRequest']
_GETLATESTSUCCESSFULJOBRESPONSE = DESCRIPTOR.message_types_by_name['GetLatestSuccessfulJobResponse']
_DELETEFEATURESETJOBSREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeatureSetJobsRequest']
_DELETEFEATURESETJOBSRESPONSE = DESCRIPTOR.message_types_by_name['DeleteFeatureSetJobsResponse']
ApplyJobRequest = _reflection.GeneratedProtocolMessageType('ApplyJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPLYJOBREQUEST,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.ApplyJobRequest)
  })
_sym_db.RegisterMessage(ApplyJobRequest)

ApplyJobResponse = _reflection.GeneratedProtocolMessageType('ApplyJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPLYJOBRESPONSE,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.ApplyJobResponse)
  })
_sym_db.RegisterMessage(ApplyJobResponse)

InitPaginationRequest = _reflection.GeneratedProtocolMessageType('InitPaginationRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITPAGINATIONREQUEST,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.InitPaginationRequest)
  })
_sym_db.RegisterMessage(InitPaginationRequest)

InitPaginationResponse = _reflection.GeneratedProtocolMessageType('InitPaginationResponse', (_message.Message,), {
  'DESCRIPTOR' : _INITPAGINATIONRESPONSE,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.InitPaginationResponse)
  })
_sym_db.RegisterMessage(InitPaginationResponse)

ListJobsRequest = _reflection.GeneratedProtocolMessageType('ListJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTJOBSREQUEST,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.ListJobsRequest)
  })
_sym_db.RegisterMessage(ListJobsRequest)

ListJobsResponse = _reflection.GeneratedProtocolMessageType('ListJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTJOBSRESPONSE,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.ListJobsResponse)
  })
_sym_db.RegisterMessage(ListJobsResponse)

GetJobLogsRequest = _reflection.GeneratedProtocolMessageType('GetJobLogsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBLOGSREQUEST,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.GetJobLogsRequest)
  })
_sym_db.RegisterMessage(GetJobLogsRequest)

GetJobLogsResponse = _reflection.GeneratedProtocolMessageType('GetJobLogsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBLOGSRESPONSE,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.GetJobLogsResponse)
  })
_sym_db.RegisterMessage(GetJobLogsResponse)

GetLatestSuccessfulJobRequest = _reflection.GeneratedProtocolMessageType('GetLatestSuccessfulJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLATESTSUCCESSFULJOBREQUEST,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.GetLatestSuccessfulJobRequest)
  })
_sym_db.RegisterMessage(GetLatestSuccessfulJobRequest)

GetLatestSuccessfulJobResponse = _reflection.GeneratedProtocolMessageType('GetLatestSuccessfulJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLATESTSUCCESSFULJOBRESPONSE,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.GetLatestSuccessfulJobResponse)
  })
_sym_db.RegisterMessage(GetLatestSuccessfulJobResponse)

DeleteFeatureSetJobsRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureSetJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURESETJOBSREQUEST,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.DeleteFeatureSetJobsRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureSetJobsRequest)

DeleteFeatureSetJobsResponse = _reflection.GeneratedProtocolMessageType('DeleteFeatureSetJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURESETJOBSRESPONSE,
  '__module__' : 'qwak.feature_store.jobs.job_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.jobs.DeleteFeatureSetJobsResponse)
  })
_sym_db.RegisterMessage(DeleteFeatureSetJobsResponse)

_JOBSERVICE = DESCRIPTOR.services_by_name['JobService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"com.qwak.ai.feature.store.jobs.apiP\001Z\022qwak/fsjobs;fsjobs'
  _APPLYJOBREQUEST._serialized_start=106
  _APPLYJOBREQUEST._serialized_end=251
  _APPLYJOBRESPONSE._serialized_start=253
  _APPLYJOBRESPONSE._serialized_end=295
  _INITPAGINATIONREQUEST._serialized_start=297
  _INITPAGINATIONREQUEST._serialized_end=346
  _INITPAGINATIONRESPONSE._serialized_start=348
  _INITPAGINATIONRESPONSE._serialized_end=411
  _LISTJOBSREQUEST._serialized_start=413
  _LISTJOBSREQUEST._serialized_end=514
  _LISTJOBSRESPONSE._serialized_start=516
  _LISTJOBSRESPONSE._serialized_end=593
  _GETJOBLOGSREQUEST._serialized_start=595
  _GETJOBLOGSREQUEST._serialized_end=630
  _GETJOBLOGSRESPONSE._serialized_start=632
  _GETJOBLOGSRESPONSE._serialized_end=678
  _GETLATESTSUCCESSFULJOBREQUEST._serialized_start=680
  _GETLATESTSUCCESSFULJOBREQUEST._serialized_end=757
  _GETLATESTSUCCESSFULJOBRESPONSE._serialized_start=759
  _GETLATESTSUCCESSFULJOBRESPONSE._serialized_end=864
  _DELETEFEATURESETJOBSREQUEST._serialized_start=866
  _DELETEFEATURESETJOBSREQUEST._serialized_end=921
  _DELETEFEATURESETJOBSRESPONSE._serialized_start=923
  _DELETEFEATURESETJOBSRESPONSE._serialized_end=988
  _JOBSERVICE._serialized_start=991
  _JOBSERVICE._serialized_end=1689
# @@protoc_insertion_point(module_scope)
