"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.message
import qwak.administration.authenticated_user.v1.credentials_pb2
import qwak.administration.authenticated_user.v1.details_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetDetailsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetDetailsRequest = GetDetailsRequest

class GetDetailsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> qwak.administration.authenticated_user.v1.details_pb2.UserDetails:
        """The authenticated user details"""
    @property
    def environment(self) -> qwak.administration.authenticated_user.v1.details_pb2.EnvironmentDetails:
        """The authenticated user environment"""
    def __init__(
        self,
        *,
        user: qwak.administration.authenticated_user.v1.details_pb2.UserDetails | None = ...,
        environment: qwak.administration.authenticated_user.v1.details_pb2.EnvironmentDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["environment", b"environment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment", b"environment", "user", b"user"]) -> None: ...

global___GetDetailsResponse = GetDetailsResponse

class GetEnvironmentDetailsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GetEnvironmentDetailsRequest = GetEnvironmentDetailsRequest

class GetEnvironmentDetailsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_FIELD_NUMBER: builtins.int
    @property
    def environment(self) -> qwak.administration.authenticated_user.v1.details_pb2.EnvironmentDetails:
        """The authenticated user environment"""
    def __init__(
        self,
        *,
        environment: qwak.administration.authenticated_user.v1.details_pb2.EnvironmentDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["environment", b"environment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment", b"environment"]) -> None: ...

global___GetEnvironmentDetailsResponse = GetEnvironmentDetailsResponse

class GetCloudCredentialsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DURATION_FIELD_NUMBER: builtins.int
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration", b"duration"]) -> None: ...

global___GetCloudCredentialsRequest = GetCloudCredentialsRequest

class GetCloudCredentialsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_CREDENTIALS_FIELD_NUMBER: builtins.int
    @property
    def cloud_credentials(self) -> qwak.administration.authenticated_user.v1.credentials_pb2.CloudCredentials:
        """The credentials of the environment in the cloud provider"""
    def __init__(
        self,
        *,
        cloud_credentials: qwak.administration.authenticated_user.v1.credentials_pb2.CloudCredentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_credentials", b"cloud_credentials"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_credentials", b"cloud_credentials"]) -> None: ...

global___GetCloudCredentialsResponse = GetCloudCredentialsResponse
